@@ -38,7 +38,7 @@ class Factory:
         locale = locale.replace('-', '_') if locale else DEFAULT_LOCALE
         locale = pylocale.normalize(locale).split('.')[0]
         if locale not in AVAILABLE_LOCALES:
-            msg = 'Invalid configuration for faker locale `{}`'.format(locale)
+            msg = f'Invalid configuration for faker locale `{locale}`'
             raise AttributeError(msg)
 
         config['locale'] = locale
@@ -81,8 +81,7 @@ class Factory:
         if provider_class:
             return provider_class, None
 
-        msg = 'Unable to find provider `{}` with locale `{}`'.format(
-            provider, locale)
+        msg = f'Unable to find provider `{provider}` with locale `{locale}`'
         raise ValueError(msg)
 
     @classmethod
@@ -92,36 +91,28 @@ class Factory:
 
         if getattr(provider_module, 'localized', False):
 
-            logger.debug('Looking for locale `{}` in provider `{}`.'.format(
-                locale, provider_module.__name__))
+            logger.debug('Looking for locale `%s` in provider `%s`.', locale, provider_module.__name__)
 
             available_locales = list_module(provider_module)
             if not locale or locale not in available_locales:
                 unavailable_locale = locale
                 locale = getattr(
                     provider_module, 'default_locale', DEFAULT_LOCALE)
-                logger.debug('Specified locale `{}` is not available for '
-                             'provider `{}`. Locale reset to `{}` for this '
-                             'provider.'.format(
-                                 unavailable_locale, provider_module.__name__, locale),
-                             )
+                logger.debug('Specified locale `%s` is not available for '
+                             'provider `%s`. Locale reset to `%s` for this '
+                             'provider.',
+                             unavailable_locale, provider_module.__name__, locale)
             else:
-                logger.debug('Provider `{}` has been localized to `{}`.'.format(
-                    provider_module.__name__, locale))
+                logger.debug('Provider `%s` has been localized to `%s`.', provider_module.__name__, locale)
 
-            path = "{provider_path}.{locale}".format(
-                provider_path=provider_path,
-                locale=locale,
-            )
+            path = f'{provider_path}.{locale}'
             provider_module = import_module(path)
 
         else:
 
-            logger.debug('Provider `{}` does not feature localization. '
-                         'Specified locale `{}` is not utilized for this '
-                         'provider.'.format(
-                             provider_module.__name__, locale),
-                         )
+            logger.debug('Provider `%s` does not feature localization. '
+                         'Specified locale `%s` is not utilized for this '
+                         'provider.', provider_module.__name__, locale)
 
             if locale is not None:
                 provider_module = import_module(provider_path)
